from setuptools import setup

setup(
    name="ycecream",
    packages=["ycecream"],
    version="1.1.2",
    include_package_data=True,
    long_description="ycecream",
    description="ycecream",
    author="Ruud van der Ham",
    author_email="info@salabim.org",
    url="https://github.com/salabim/ycecream",
    download_url="https://github.com/salabim/ycecream",
    keywords=["debugging", "utility", "tool"],
    classifiers=[],
)
